# Sapyens — SQLAlchemy & Pyramid enhancements

## Features
* sapyens.crud — customizable generic views and templates for CRUD building
* sapyens.db — SQLAlchemy helpers (initialisation, base classes, etc.)
* sapyens.helpers — various
* sapyens.migrate — plain SQL migration
* sapyens.script — console script base
* sapyens.views — generic views

## License
[The MIT License](http://www.opensource.org/licenses/mit-license.php)
